@@ -68,13 +68,39 @@ predict.decomposition <- function(object,n_ahead,only_new = TRUE,...){
 
 }
 
+
+#' @title Notify User prediction warning on constant is 0
+#' @description Notfy the user of details related to the outputs of the model being potentially inaccurate when constant of model is 0. 
+#' @export
+#' @param constant The B_0 parameter of the model.
+#'
+#' @return No return value
+#'
+#'
+#'
+
+prediction_warning <- function(constant)
+{
+
+  if(is.numeric(constant))
+  {
+      if(constant == 0)
+    {
+      message("WARNING : the model's constant (Beta_0) parameter is 0. This will result in likely inaccurate predictions.")
+      message("The model constant is understood as the mean log adjusted monthly visitation relative to the base month.")
+      message("Please provide a ref_series to the visitation_model object or provide your own custom value for the constant to visitation_model constructor")
+    }
+  }
+
+
+}
+
 #' @title Predict Visitation Model
 #' @description Methods for generating predictions from objects of the class "visitation_model".
 #' @export
 #' @param object An object of class "visitation_model".
 #' @param n_ahead An integer indicating how many observations to forecast.
 #' @param only_new A Boolean specifying whether to include only the forecasts (if TRUE) or the full reconstruction (if FALSE). The default option is TRUE.
-#' @param difference A Boolean specifying whether to forecast differences (if TRUE) or the original series (if FALSE). The default option is FALSE.
 #' @param past_observations A character string; one of "fitted" or "reference". Here, "fitted" uses the fitted values of the visitation model, while "reference" uses values supplied in `ref_series'.
 #' @param ... Additional arguments.
 #'
@@ -105,22 +131,20 @@ predict.decomposition <- function(object,n_ahead,only_new = TRUE,...){
 #' popularity_proxy <- log(flickr_userdays)
 #'
 #' vm <- visitation_model(pud_ts,popularity_proxy, ref_series = nps_ts, trend = "linear")
-#' predict_vm <- predict(vm,n_ahead, difference = TRUE,
+#' predict_vm <- predict(vm,n_ahead,
 #'                       only_new = FALSE, past_observations = "reference")
-#' plot(predict_vm, difference = FALSE)
-#' predict_vm2 <- predict(vm,n_ahead, difference = TRUE,
+#' plot(predict_vm, )
+#' predict_vm2 <- predict(vm,n_ahead,
 #'                        only_new = FALSE, past_observations = "reference")
-#' plot(predict_vm2, difference = FALSE)
+#' plot(predict_vm2)
 
 
 predict.visitation_model <- function(object,
                                      n_ahead,
                                      only_new = TRUE,
-                                     difference = FALSE,
                                      past_observations = c("fitted","reference"),
                                      ...){
 
-
   past_observations <- match.arg(past_observations)
 
   trend <- object$trend
@@ -145,21 +169,19 @@ predict.visitation_model <- function(object,
 
   if(trend == "estimated"){
     proxy_trend_forecasts <- generate_proxy_trend_forecasts(object,n_ahead,starttime,endtime, proxy_trend_correction, ts_frequency)
-    forecasts <- log(object$constant)+time_series_forecasts$trend_forecast-proxy_trend_forecasts+object$beta*time_series_forecasts$seasonality_forecast
+    forecasts <- object$constant+time_series_forecasts$trend_forecast-proxy_trend_forecasts+object$beta*time_series_forecasts$seasonality_forecast
   }
   if(trend == "none"){
-    # note that object$constant is generated by exp() in visitation_model()
     proxy_trend_forecasts <- numeric(n_ahead)
-    forecasts <- log(object$constant)+object$beta*time_series_forecasts$seasonality_forecast
+    forecasts <- object$constant+object$beta*time_series_forecasts$seasonality_forecast
   }
   if(trend == "linear"){
-    # note that object$constant is generated by exp() in visitation_model()
     proxy_trend_forecasts <- numeric(n_ahead)
     months_ahead <- (length(object$visitation_fit)+1):(length(object$visitation_fit)+n_ahead)
-    forecasts <- log(object$constant)+object$beta*time_series_forecasts$seasonality_forecast+object$slope*months_ahead
+    forecasts <- object$constant+object$beta*time_series_forecasts$seasonality_forecast+object$slope*months_ahead
   }
 
-  ### if difference or only_new = FALSE, combine past observations series with forecasts.
+  ### if only_new = FALSE, combine past observations series with forecasts.
 
   if(identical(past_observations,"fitted")){
     past_values <- object$visitation_fit
@@ -176,17 +198,20 @@ predict.visitation_model <- function(object,
     past <- past_values
     forecasts <- c(past,forecasts)
   }
-  if(difference & only_new){
-    past <- past_values[length(object$visitation_fit)]
+  if(only_new){
+    past <- past_values[length(object$visitation_fit)] 
     forecasts <- c(past,forecasts)
   }
 
   forecasts <-  ts(forecasts,
                    end = time(object$visitation_fit)[length(object$visitation_fit)]+n_ahead/frequency(object$visitation_fit),
                    frequency = frequency(object$visitation_fit))
-  if(difference){
-    forecasts <- diff(forecasts)
-  }
+
+
+  logged_forecasts <-forecasts
+  differenced_logged_forecasts <-diff(forecasts)
+  standard_forecasts <-exp(logged_forecasts)
+  differenced_standard_forecasts <-exp(differenced_logged_forecasts)
 
   if(trend == "none"||trend == "linear")
   {
@@ -197,7 +222,13 @@ predict.visitation_model <- function(object,
     lag_estimate <- -proxy_trend_correction
   }
 
-  return(new_visitation_forecast(forecasts = forecasts,
+  prediction_warning(object$constant)
+
+  return(new_visitation_forecast(
+                                 logged_forecasts = logged_forecasts,
+                                 forecasts = standard_forecasts, 
+                                 differenced_logged_forecasts = differenced_logged_forecasts,
+                                 differenced_standard_forecasts = differenced_standard_forecasts,
                                  n_ahead = n_ahead,
                                  proxy_forecasts = proxy_trend_forecasts,
                                  onsite_usage_forecasts = time_series_forecasts,
